package com.ruoyi.project.system.service;

import java.util.List;
import com.ruoyi.project.system.domain.TAlarmPrincipal;

/**
 * 预警管理负责人Service接口
 * 
 * @author ruoyi
 * @date 2020-12-30
 */
public interface ITAlarmPrincipalService 
{
    /**
     * 查询预警管理负责人
     * 
     * @param id 预警管理负责人ID
     * @return 预警管理负责人
     */
    public TAlarmPrincipal selectTAlarmPrincipalById(Long id);

    /**
     * 查询预警管理负责人列表
     * 
     * @param tAlarmPrincipal 预警管理负责人
     * @return 预警管理负责人集合
     */
    public List<TAlarmPrincipal> selectTAlarmPrincipalList(TAlarmPrincipal tAlarmPrincipal);

    /**
     * 定时任务查询预警管理负责人列表
     *
     * @param tAlarmPrincipal 预警管理负责人
     * @return 预警管理负责人
     */
    public List<TAlarmPrincipal> selectList(TAlarmPrincipal tAlarmPrincipal);

    /**
     * 新增预警管理负责人
     * 
     * @param tAlarmPrincipal 预警管理负责人
     * @return 结果
     */
    public int insertTAlarmPrincipal(TAlarmPrincipal tAlarmPrincipal);

    /**
     * 修改预警管理负责人
     * 
     * @param tAlarmPrincipal 预警管理负责人
     * @return 结果
     */
    public int updateTAlarmPrincipal(TAlarmPrincipal tAlarmPrincipal);

    /**
     * 批量删除预警管理负责人
     * 
     * @param ids 需要删除的预警管理负责人ID
     * @return 结果
     */
    public int deleteTAlarmPrincipalByIds(Long[] ids);

    /**
     * 删除预警管理负责人信息
     * 
     * @param id 预警管理负责人ID
     * @return 结果
     */
    public int deleteTAlarmPrincipalById(Long id);
}
